@@ -2,6 +2,15 @@ import xlfly.create_shortcut
 import os
 import xlfly.configs as configs
 import argparse
+import importlib
+
+
+def init_default(default_init_file: str):
+    print(f"init file:{default_init_file}")
+    spec = importlib.util.spec_from_file_location("__init__", default_init_file)
+    init = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(init)
+    init.setup()
 
 
 def main():
@@ -23,6 +32,10 @@ def main():
             print(f"Selected folder: {folder_path}")
             settings["tempfolder"] = folder_path
             configs.save_settings(settings)
+            print("Initilizing default init...")
+            default_init_file = os.path.join(folder_path, "default", "__init__.py")
+            init_default(default_init_file)
+            print("Done")
 
 
 if __name__ == "__main__":
